@@ -1,4 +1,4 @@
-/* Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1335  USA */
+ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 #ifndef MY_CONFIG_H
 #define MY_CONFIG_H
@@ -22,7 +22,7 @@
 #define HAVE_ALLOCA_H 1
 #define HAVE_AIO_H 1
 #define HAVE_ARPA_INET_H 1
-#define HAVE_ASM_MSR_H 1
+/* #undef HAVE_ASM_MSR_H */
 #define HAVE_ASM_TERMBITS_H 1
 #define HAVE_BSEARCH 1
 #define HAVE_CRYPT_H 1
@@ -41,11 +41,10 @@
 #define HAVE_FNMATCH_H 1
 #define HAVE_FPU_CONTROL_H 1
 #define HAVE_GRP_H 1
-#define HAVE_EXPLICIT_TEMPLATE_INSTANTIATION 1
+/* #undef HAVE_EXPLICIT_TEMPLATE_INSTANTIATION */
 /* #undef HAVE_IA64INTRIN_H */
 /* #undef HAVE_IEEEFP_H */
 #define HAVE_INTTYPES_H 1
-/* #undef HAVE_KQUEUE */
 #define HAVE_LIMITS_H 1
 #define HAVE_LINUX_UNISTD_H 1
 #define HAVE_LOCALE_H 1
@@ -95,7 +94,6 @@
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_UN_H 1
 /* #undef HAVE_SYS_VADVISE_H */
-#define HAVE_UCONTEXT_H 1
 #define HAVE_TERM_H 1
 /* #undef HAVE_TERMBITS_H */
 #define HAVE_TERMIOS_H 1
@@ -148,7 +146,6 @@
 #define HAVE_CUSERID 1
 #define HAVE_CXX_NEW 1
 /* #undef HAVE_DIRECTIO */
-#define HAVE_DLADDR 1
 #define HAVE_DLERROR 1
 #define HAVE_DLOPEN 1
 /* #undef HAVE_DOPRNT */
@@ -320,15 +317,13 @@
 /* #undef HAVE_TIMESPEC_TS_SEC */
 #define STRUCT_DIRENT_HAS_D_INO 1
 /* #undef STRUCT_DIRENT_HAS_D_NAMLEN */
-#define STRUCT_TIMESPEC_HAS_TV_SEC 1
-#define STRUCT_TIMESPEC_HAS_TV_NSEC 1
 #define SPRINTF_RETURNS_INT 1
 
 #define USE_MB 1
 #define USE_MB_IDENT 1
 
 /* this means that valgrind headers and macros are available */
-#define HAVE_VALGRIND 1
+/* #undef HAVE_VALGRIND */
 
 /* this means WITH_VALGRIND - we change some code paths for valgrind */
 /* #undef HAVE_valgrind */
@@ -399,7 +394,7 @@
 
 #define SOCKET_SIZE_TYPE socklen_t
 
-#define HAVE_MBSTATE_T 1
+#define HAVE_MBSTATE_T
 
 #define MAX_INDEXES 64
 
@@ -434,15 +429,15 @@
 #define HAVE_WCTYPE_H 1
 #define HAVE_WCHAR_H 1
 #define HAVE_LANGINFO_H 1
-#define HAVE_MBRLEN 1
+#define HAVE_MBRLEN
 /* #undef HAVE_MBSCMP */
-#define HAVE_MBSRTOWCS 1
-#define HAVE_WCRTOMB 1
-#define HAVE_MBRTOWC 1
-#define HAVE_WCSCOLL 1
-#define HAVE_WCSDUP 1
-#define HAVE_WCWIDTH 1
-#define HAVE_WCTYPE 1
+#define HAVE_MBSRTOWCS
+#define HAVE_WCRTOMB
+#define HAVE_MBRTOWC
+#define HAVE_WCSCOLL
+#define HAVE_WCSDUP
+#define HAVE_WCWIDTH
+#define HAVE_WCTYPE
 #define HAVE_ISWLOWER 1
 #define HAVE_ISWUPPER 1
 #define HAVE_TOWLOWER 1
@@ -456,7 +451,7 @@
 #define HAVE_STRCASECMP 1
 #define HAVE_STRNCASECMP 1
 #define HAVE_STRDUP 1
-#define HAVE_LANGINFO_CODESET  1
+#define HAVE_LANGINFO_CODESET 
 #define HAVE_TCGETATTR 1
 #define HAVE_FLOCKFILE 1
 
@@ -468,7 +463,7 @@
 /* #undef HAVE_BSD_SIGNALS */
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
-/* #undef HAVE_ERR_remove_thread_state */
+
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
@@ -485,6 +480,7 @@
 /* #undef _LARGE_FILES */
 #define _LARGEFILE_SOURCE 1
 /* #undef _LARGEFILE64_SOURCE */
+#define _FILE_OFFSET_BITS 64
 
 #define TIME_WITH_SYS_TIME 1
 
@@ -517,10 +513,6 @@
 /* #undef strtoll */
 /* #undef strtoull */
 /* #undef vsnprintf */
-#if (_MSC_VER > 1800)
-#define tzname _tzname
-#define P_tmpdir "C:\\TEMP"
-#endif
 #if (_MSC_VER > 1310)
 # define HAVE_SETENV
 #define setenv(a,b,c) _putenv_s(a,b)
@@ -530,11 +522,7 @@
 /*
   MySQL features
 */
-#define LOCAL_INFILE_MODE_OFF  0
-#define LOCAL_INFILE_MODE_ON   1
-#define LOCAL_INFILE_MODE_AUTO 2
-#define ENABLED_LOCAL_INFILE LOCAL_INFILE_MODE_AUTO
-
+#define ENABLED_LOCAL_INFILE 1
 #define ENABLED_PROFILING 1
 /* #undef EXTRA_DEBUG */
 /* #undef BACKUP_TEST */
@@ -611,7 +599,7 @@
 #define WITH_MYISAMMRG_STORAGE_ENGINE 1
 #define WITH_HEAP_STORAGE_ENGINE 1
 #define WITH_INNOBASE_STORAGE_ENGINE 1
-#define WITH_XTRADB_STORAGE_ENGINE 1
+/* #undef WITH_XTRADB_STORAGE_ENGINE */
 #define WITH_CSV_STORAGE_ENGINE 1
 #define WITH_PARTITION_STORAGE_ENGINE 1
 #define WITH_PERFSCHEMA_STORAGE_ENGINE 1
@@ -629,20 +617,21 @@
 #define DEFAULT_CHARSET_HOME "/usr/local/mysql"
 #define PLUGINDIR "/usr/local/mysql/lib/plugin"
 /* #undef DEFAULT_SYSCONFDIR */
-#define DEFAULT_TMPDIR P_tmpdir
 
 /* #undef SO_EXT */
 
-#define MYSQL_MAJOR_VERSION 5
-#define MYSQL_MINOR_VERSION 5
+#define MYSQL_MAJOR_VERSION 10
+#define MYSQL_MINOR_VERSION 0
+#define MYSQL_VERSION_PATCH 0
+#define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.5.68"
+#define PACKAGE_STRING "MySQL Server 10.0.0"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.5.68"
-#define VERSION "5.5.68"
+#define PACKAGE_VERSION "10.0.0"
+#define VERSION "10.0.0"
 #define PROTOCOL_VERSION 10
 
 
